@@ -10,7 +10,6 @@
 WvFile::WvFile()
 {
     readable = writable = false;
-    skip_select = false;
 }
 
 #ifndef _WIN32 // meaningless to do this on win32
@@ -31,8 +30,6 @@ WvFile::WvFile(int rwfd) : WvFDStream(rwfd)
     }
     else
 	readable = writable = false;
-
-    skip_select = false;
 }
 #endif
 
@@ -72,8 +69,6 @@ bool WvFile::open(WvStringParm filename, int mode, int create_mode)
     readable = (xmode == O_RDONLY) || (xmode == O_RDWR);
     writable = (xmode == O_WRONLY) || (xmode == O_RDWR);
 
-    skip_select = false;
-    
     // don't do the default force_select of read if we're not readable!
     if (!readable)
 	undo_force_select(true, false, false);
@@ -112,8 +107,6 @@ bool WvFile::open(int _rwfd)
     readable = (xmode == O_RDONLY) || (xmode == O_RDWR);
     writable = (xmode == O_WRONLY) || (xmode == O_RDWR);
 
-    skip_select = false;
-    
     if (!readable)
 	undo_force_select(true, false, false);
 
@@ -129,24 +122,12 @@ bool WvFile::open(int _rwfd)
 
 // files not open for read are never readable; files not open for write
 // are never writable.
-bool WvFile::pre_select(SelectInfo &si)
+void WvFile::pre_select(SelectInfo &si)
 {
-    bool ret;
-    
-    SelectRequest oldwant = si.wants;
-    
+    SelectRequest oldwant = si.wants;    
     if (!readable) si.wants.readable = false;
     if (!writable) si.wants.writable = false;
-    ret = WvFDStream::pre_select(si);
-    
-    si.wants = oldwant;
 
-    // Force select() to always return true by causing it to not wait and
-    // setting our pre_select() return value to true.
-    if (skip_select)
-    {
-	si.msec_timeout = 0;
-	ret = true;
-    }
-    return ret;
+    WvFDStream::pre_select(si);    
+    si.wants = oldwant;
 }
