@@ -572,7 +572,7 @@ char *WvStream::blocking_getline(time_t wait_msec, int separator,
     
     //assert(uses_continue_select || wait_msec == 0);
 
-    struct timeval timeout_time;
+    WvTime timeout_time(0);
     if (wait_msec > 0)
         timeout_time = msecadd(wvtime(), wait_msec);
     
@@ -806,14 +806,17 @@ void WvStream::flush_then_close(int msec_timeout)
 }
 
 
-bool WvStream::pre_select(SelectInfo &si)
+void WvStream::pre_select(SelectInfo &si)
 {
     maybe_autoclose();
     
     time_t alarmleft = alarm_remaining();
     
     if (!si.inherit_request && alarmleft == 0)
-	return true; // alarm has rung
+    {
+	si.msec_timeout = 0;
+	return; // alarm has rung
+    }
 
     if (!si.inherit_request)
     {
@@ -824,11 +827,13 @@ bool WvStream::pre_select(SelectInfo &si)
     
     // handle read-ahead buffering
     if (si.wants.readable && inbuf.used() && inbuf.used() >= queue_min)
-	return true; // already ready
+    {
+	si.msec_timeout = 0; // already ready
+	return;
+    }
     if (alarmleft >= 0
       && (alarmleft < si.msec_timeout || si.msec_timeout < 0))
 	si.msec_timeout = alarmleft + 10;
-    return false;
 }
 
 
@@ -844,11 +849,14 @@ bool WvStream::post_select(SelectInfo &si)
 	flush(0);
     if (!si.inherit_request && alarm_remaining() == 0)
 	return true; // alarm ticked
+    if ((si.wants.readable || (!si.inherit_request && readcb))
+	&& inbuf.used() && inbuf.used() >= queue_min)
+	return true; // already ready
     return false;
 }
 
 
-bool WvStream::_build_selectinfo(SelectInfo &si, time_t msec_timeout,
+void WvStream::_build_selectinfo(SelectInfo &si, time_t msec_timeout,
     bool readable, bool writable, bool isexcept, bool forceable)
 {
     FD_ZERO(&si.read);
@@ -873,21 +881,18 @@ bool WvStream::_build_selectinfo(SelectInfo &si, time_t msec_timeout,
     si.inherit_request = ! forceable;
     si.global_sure = false;
 
-    if (!isok()) return false;
+    if (!isok()) return;
 
     wvstime_sync();
 
-    bool sure = pre_select(si);
+    pre_select(si);
     if (globalstream && forceable && (globalstream != this))
     {
 	WvStream *s = globalstream;
 	globalstream = NULL; // prevent recursion
-	si.global_sure = s->xpre_select(si, SelectRequest(false, false, false));
+	s->xpre_select(si, SelectRequest(false, false, false));
 	globalstream = s;
     }
-    if (sure || si.global_sure)
-        si.msec_timeout = 0;
-    return sure;
 }
 
 
@@ -933,7 +938,12 @@ bool WvStream::_process_selectinfo(SelectInfo &si, bool forceable)
 {
     if (!isok()) return false;
 
-    wvstime_sync();
+    // We cannot move the clock backward here, because timers that
+    // were expired in pre_select could then not be expired anymore,
+    // and while time going backward is rather unsettling in general,
+    // for it to be happening between pre_select and post_select is
+    // just outright insanity.
+    wvstime_sync_forward();
         
     bool sure = post_select(si);
     if (globalstream && forceable && (globalstream != this))
@@ -954,25 +964,19 @@ bool WvStream::_select(time_t msec_timeout,
     assert(wsid_map && wsid_map->exists(my_wsid)); // Detect use of deleted stream
         
     SelectInfo si;
-    bool sure = _build_selectinfo(si, msec_timeout,
-				  readable, writable, isexcept, forceable);
+    _build_selectinfo(si, msec_timeout,
+                      readable, writable, isexcept, forceable);
     
     if (!isok())
 	return false;
     
-    // the eternal question: if 'sure' is true already, do we need to do the
-    // rest of this stuff?  If we do, it might increase fairness a bit, but
-    // it encourages select()ing when we know something fishy has happened -
-    // when a stream is !isok() in a list, for example, pre_select() returns
-    // true.  If that's the case, our SelectInfo structure might not be
-    // quite right (eg. it might be selecting on invalid fds).  That doesn't
-    // sound *too* bad, so let's go for the fairness.
-
+    bool sure = false;
     int sel = _do_select(si);
     if (sel >= 0)
-        sure = _process_selectinfo(si, forceable) || sure; // note the order
+        sure = _process_selectinfo(si, forceable); 
     if (si.global_sure && globalstream && forceable && (globalstream != this))
 	globalstream->callback();
+
     return sure;
 }
 
