@@ -27,7 +27,9 @@ static WvMoniker<IWvStream> reg("clone", creator);
 
 
 WvStreamClone::WvStreamClone(IWvStream *_cloned) 
-    : cloned(0), disassociate_on_close(false), my_type("WvStreamClone:(none)")
+    : cloned(0), 
+      disassociate_on_close(false), 
+      my_type("WvStreamClone:(none)")
 {
     setclone(_cloned);
     // the sub-stream will force its own values, if it really wants.
@@ -184,10 +186,11 @@ void WvStreamClone::setclone(IWvStream *newclone)
 }
 
 
-bool WvStreamClone::pre_select(SelectInfo &si)
+void WvStreamClone::pre_select(SelectInfo &si)
 {
     SelectRequest oldwant;
-    bool result = WvStream::pre_select(si);
+    WvStream::pre_select(si);
+
     if (cloned && cloned->isok())
     {
 	oldwant = si.wants;
@@ -202,12 +205,11 @@ bool WvStreamClone::pre_select(SelectInfo &si)
 	
 	if (outbuf.used() || autoclose_time)
 	    si.wants.writable = true;
-	
-	result = result || cloned->pre_select(si);
-	
+
+	cloned->pre_select(si);
+
 	si.wants = oldwant;
     }
-    return result;
 }
 
 
