@@ -2,6 +2,8 @@
 #include "uniconfroot.h"
 #include "unitempgen.h"
 #include "uniretrygen.h"
+#include "uniclientgen.h"
+#include "uniconfgen-sanitytest.h"
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -21,48 +23,6 @@ struct UniRetryGenTester
 };
 
 
-static void kill_and_wait(pid_t _pid)
-{
-    // Never ever try to fiddle with pid 0 or -1
-    if (_pid <=  0)
-        return;
-
-    kill(_pid, 15);
-    int status;
-    pid_t rv = waitpid(_pid, &status, 0);
-
-    while (rv == -1 && errno == EINTR)
-	rv = waitpid(_pid, &status, 0);
-
-    // This fails randomly on SMP systems, and I wish I knew why.
-    //WVPASSEQ(rv, _pid);
-    //WVPASS(WIFEXITED(status));
-}
-
-
-void start_uniconfd(UniRetryGenTester &t)
-{
-    WvString iniarg("ini:%s", t.ini);
-    char *argv[] = {
-	"uniconfd",
-	"-f",
-	"-p", "0",
-	"-s", "0",
-	"-u", t.socket.edit(),
-	iniarg.edit(),
-	NULL
-    };
-
-    unlink(t.socket);
-    if ((t.uniconfd_pid = fork()) == 0)
-    {
-    	execv("uniconf/daemon/uniconfd", argv);
-    	_exit(1);
-    }
-    sleep(1);
-}
-
-
 void wait_for_connect(UniRetryGenTester t)
 {
     UniConfRoot another_cfg(WvString("retry:unix:%s", t.socket));
@@ -78,6 +38,13 @@ void wait_for_connect(UniRetryGenTester t)
 }
 
 
+WVTEST_MAIN("UniRetryGen Sanity Test")
+{
+    UniRetryGen *gen = new UniRetryGen("temp:");
+    UniConfGenSanityTester::sanity_test(gen, "retry:temp:");
+    WVRELEASE(gen);
+}
+
 WVTEST_MAIN("UniRetryGen: uniconfd")
 {
     signal(SIGPIPE, SIG_IGN);
@@ -90,24 +57,26 @@ WVTEST_MAIN("UniRetryGen: uniconfd")
     cfg["/key"].setme("value");
     WVPASS(!cfg["/key"].exists());
 
-    start_uniconfd(t);
-    wait_for_connect(t);
+    {
+        UniConfTestDaemon daemon(t.socket, WvString("ini:%s", t.ini));
+        wait_for_connect(t);
 
-    cfg["/key"].setme("value");
-    WVPASSEQ(cfg["/key"].getme(), "value");
-    
-    cfg.commit();
-    kill_and_wait(t.uniconfd_pid);
+        cfg["/key"].setme("value");
+        WVPASSEQ(cfg["/key"].getme(), "value");
+        
+        cfg.commit();
+    }
     
     WVPASS(!cfg["/key"].exists());
     
-    start_uniconfd(t);
-    wait_for_connect(t);
-    
-    WVPASSEQ(cfg["/key"].getme(), "value");
-    
-    cfg.commit();
-    kill_and_wait(t.uniconfd_pid);
+    {
+        UniConfTestDaemon daemon(t.socket, WvString("ini:%s", t.ini));
+        wait_for_connect(t);
+        
+        WVPASSEQ(cfg["/key"].getme(), "value");
+        
+        cfg.commit();
+    }
 
     WVPASS(!cfg["/key"].exists());
 }
@@ -129,14 +98,11 @@ WVTEST_MAIN("UniRetryGen: reconnect callback")
 
     reconnected = false;
 
-    start_uniconfd(t);
-
+    UniConfTestDaemon daemon(t.socket, WvString("ini:%s", t.ini));
     wait_for_connect(t);
     
     cfg.getme(); // Do something to reconnect
     WVPASS(reconnected);
-
-    kill_and_wait(t.uniconfd_pid);
 }
 
 WVTEST_MAIN("UniRetryGen: immediate reconnect")
@@ -150,24 +116,25 @@ WVTEST_MAIN("UniRetryGen: immediate reconnect")
     // Need to set the reconnect delay to 0 to read immediately
     UniConfRoot cfg(WvString("retry:unix:%s 0", t.socket));
 
-    start_uniconfd(t);
-    wait_for_connect(t);
+    {
+        UniConfTestDaemon daemon(t.socket, WvString("ini:%s", t.ini));
+        wait_for_connect(t);
 
-    cfg["/key"].setme("value");
-    WVPASSEQ(cfg["/key"].getme(), "value");
-    
-    cfg.commit();
-    kill_and_wait(t.uniconfd_pid);
+        cfg["/key"].setme("value");
+        WVPASSEQ(cfg["/key"].getme(), "value");
+        
+        cfg.commit();
+    }
     
     // don't check anything before restarting so cfg doesn't know that
     // uniconfd has disconnected.
-    start_uniconfd(t);
-    wait_for_connect(t);
+    {
+        UniConfTestDaemon daemon(t.socket, WvString("ini:%s", t.ini));
+        wait_for_connect(t);
 
-    cfg.getme(); // Do something to reconnect
-    WVPASSEQ(cfg["/key"].getme(), "value");
-
-    kill_and_wait(t.uniconfd_pid);
+        cfg.getme(); // Do something to reconnect
+        WVPASSEQ(cfg["/key"].getme(), "value");
+    }
 
     WVPASS(!cfg["/key"].exists());
 }
