@@ -1283,6 +1283,20 @@ WvString depunctuate(WvStringParm line)
     return ret;
 }
 
+
+WvString ptr2str(void* ptr)
+{
+    char buf[(sizeof(ptr) * 2) + 3];
+    int rv;
+
+    rv = snprintf(buf, sizeof(buf), "%p", ptr);
+
+    assert(rv != -1);
+
+    return buf;
+}
+
+
 // Reads the contents of a symlink.  Returns WvString::null on error.
 WvString wvreadlink(WvStringParm path)
 {
