@@ -7,6 +7,7 @@
 #else
 #include <unistd.h>
 #endif
+#include <stdio.h>
 
 /**
  * Functions in strutils.h left untested:
@@ -1092,6 +1093,7 @@ WVTEST_MAIN("sizetoa rounding")
     }
 }
 
+
 WVTEST_MAIN("wvreadlink")
 {
     WvString symlink_name("/tmp/wvreadlink.%s", getpid());
@@ -1109,4 +1111,88 @@ WVTEST_MAIN("wvreadlink")
         unlink(symlink_name);
     }
 }
+
+bool checkdateformat(WvString dtstr)
+{
+
+    char * head = dtstr.edit();
+    char * p = head;
+
+    p += 4;
+    if(*p == '-')
+        *p = '0';
+    p += 3;
+    if(*p == '-')
+        *p = '0';
+    p = head;
+
+    for(int i = 0; i < 10; i++,p++)
+        if(!isdigit(*p))
+            return false;
     
+    return true;
+}
+
+bool checktimeformat(WvString dtstr)
+{
+
+    char * head = dtstr.edit();
+    char * p = head;
+
+    p += 2;
+    if(*p == ':')
+        *p = '0';
+    p += 3;
+    if(*p == ':')
+        *p = '0';
+    p = head;
+
+    for(int i = 0; i < 8; i++,p++)
+        if(!isdigit(*p))
+            return false;
+
+   return true;         
+}
+
+bool checkdatetimeformat(WvString dtstr)
+{
+    bool res = false;
+    char * head, *p ;
+
+    head = p = dtstr.edit(); p += 10;
+    if(*p == ' ')
+    {
+        *p = 0;
+        p++;
+        WvString ds(head);
+        WvString ts(p);
+        if(checktimeformat(ts) && checkdateformat(ds))
+            res = true;
+    }
+
+    return res;
+}
+
+    
+WVTEST_MAIN("intl_datetime")
+{
+    // In order to make this test not depend on the local 
+    // time zone, dt is initialized as a number in time zone
+    // UTC, then minus the offset of current between current
+    // time zone and UTC. So that it can be compared with 
+    // those string describing UTC time. 
+    time_t dt = 1152558117;
+    struct tm *dtm = localtime(&dt);
+    dt -= dtm->tm_gmtoff;
+    
+    WVPASSEQ(intl_date(dt), "2006-07-10");
+    WVPASSEQ(intl_time(dt), "19:01:57");
+    WVPASSEQ(intl_datetime(dt), "2006-07-10 19:01:57");
+
+
+    WVPASS(checktimeformat(intl_time(dt)));
+    WVPASS(checkdateformat(intl_date(dt)));
+    WVPASS(checkdatetimeformat(intl_datetime(dt)));
+
+}
+
